---
title: 부분 취소가 불가한 케이스
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제취소/환불
seo:
  title: 부분 취소가 불가한 케이스
  description: >-
    결제수단에 따라서 부분 취소를 지원하지 않는 경우가 있습니다. 휴대폰결제, 가상계좌, 상품권 결제 등 부분 취소 불가한 내용 및 부분
    취소가 가능한 정보를 확인해보세요.
  keywords:
    - 일반결제
tags:
  - 공통
  - 결제취소-환불
pgCompanies:
  - 공통
searchTags:
  - 부분취소 케이스
  - 결제 취소
  - 부분취소 불가
  - 부분취소
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="일부 결제수단은 원천사의 정책에 따라 부분 취소를 지원하지 않는 경우도 있습니다. 
참고하실 수 있는 부분 취소가 불가한 케이스를 안내드립니다.
" />

#### **부분 취소 불가 카드**

- 국내 카드 : 선불카드기프트카드, 구매전용카드 등 일반적 개인 신용/체크 카드가 아닌 경우(카드사 정책)
- 해외 카드 : 해외 카드 결제 매입사(국내 카드사) 정책(VISA, MASTER, JCB)
- 법인카드의 경우 카드 회원이 취소를 막는 경우 (카드 소유자에 따라 상이)
- 복합결제 : 카드사 포인트 등 복합하여 결제된 거래

#### **부분 취소가 가능한 카드**

- 개인 신용카드 (비씨, 국민, 신한, 현대, 롯데, 하나(외환), 삼성카드)
- 법인 개인/공용 카드
- 체크카드(직불카드)

#### **참고사항**

- 휴대폰결제의 경우 이니시스만 부분 취소가 가능합니다. (남은 금액으로 재승인 후 원거래 전체 취소)
- 가상계좌의 경우 환불 자체가 불가한 PG사가 있으며(다날), 그 외 PG 사의 경우 별도 특약을 맺고 환불 서비스 이용이 가능합니다.
- ‘상품권 결제’의 경우, 상품권 수단별로 기준이 상이 합니다.



- 지정금액(면세,부가세,봉사료,공급가액) 파라미터를 이용하면서 포인트 결제가 함께 사용되는 경우, 대부분의 카드사는 예외 없이 부분 취소가 불가합니다.
- 원화 이외의 수단(카드사 포인트, 가맹점 쿠폰 등)으로 결제된 복합 거래와 해외 카드(해외 비자, 해외 마스터 등), 에스크로 거래 건의 경우 부분 취소가 불가합니다. \
  (단, 카드사 정책에 따라 일부 카드사에서는 복합결제 건의 부분 취소가 가능할 수 있음)
- 카드사 포인트를 사용한 카드 결제 건은 하기 카드사를 제외하고는 부분 취소가 정책적으로 불가합니다.
  - 국민, 삼성, 하나, 신한, 현대 예외
